# coding: utf-8

"""
    Pulp 3 API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_ansible.configuration import Configuration


class CollectionRead(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'href': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'namespace': 'str',
        'name': 'str',
        'deprecated': 'bool',
        'versions_url': 'str',
        'highest_version': 'str'
    }

    attribute_map = {
        'href': 'href',
        'created_at': 'created_at',
        'updated_at': 'updated_at',
        'namespace': 'namespace',
        'name': 'name',
        'deprecated': 'deprecated',
        'versions_url': 'versions_url',
        'highest_version': 'highest_version'
    }

    def __init__(self, href=None, created_at=None, updated_at=None, namespace=None, name=None, deprecated=None, versions_url=None, highest_version=None, local_vars_configuration=None):  # noqa: E501
        """CollectionRead - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._href = None
        self._created_at = None
        self._updated_at = None
        self._namespace = None
        self._name = None
        self._deprecated = None
        self._versions_url = None
        self._highest_version = None
        self.discriminator = None

        if href is not None:
            self.href = href
        self.created_at = created_at
        self.updated_at = updated_at
        if namespace is not None:
            self.namespace = namespace
        if name is not None:
            self.name = name
        self.deprecated = deprecated
        if versions_url is not None:
            self.versions_url = versions_url
        if highest_version is not None:
            self.highest_version = highest_version

    @property
    def href(self):
        """Gets the href of this CollectionRead.  # noqa: E501


        :return: The href of this CollectionRead.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this CollectionRead.


        :param href: The href of this CollectionRead.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def created_at(self):
        """Gets the created_at of this CollectionRead.  # noqa: E501


        :return: The created_at of this CollectionRead.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this CollectionRead.


        :param created_at: The created_at of this CollectionRead.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this CollectionRead.  # noqa: E501


        :return: The updated_at of this CollectionRead.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this CollectionRead.


        :param updated_at: The updated_at of this CollectionRead.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    @property
    def namespace(self):
        """Gets the namespace of this CollectionRead.  # noqa: E501


        :return: The namespace of this CollectionRead.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this CollectionRead.


        :param namespace: The namespace of this CollectionRead.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                namespace is not None and len(namespace) < 1):
            raise ValueError("Invalid value for `namespace`, length must be greater than or equal to `1`")  # noqa: E501

        self._namespace = namespace

    @property
    def name(self):
        """Gets the name of this CollectionRead.  # noqa: E501


        :return: The name of this CollectionRead.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CollectionRead.


        :param name: The name of this CollectionRead.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def deprecated(self):
        """Gets the deprecated of this CollectionRead.  # noqa: E501


        :return: The deprecated of this CollectionRead.  # noqa: E501
        :rtype: bool
        """
        return self._deprecated

    @deprecated.setter
    def deprecated(self, deprecated):
        """Sets the deprecated of this CollectionRead.


        :param deprecated: The deprecated of this CollectionRead.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and deprecated is None:  # noqa: E501
            raise ValueError("Invalid value for `deprecated`, must not be `None`")  # noqa: E501

        self._deprecated = deprecated

    @property
    def versions_url(self):
        """Gets the versions_url of this CollectionRead.  # noqa: E501


        :return: The versions_url of this CollectionRead.  # noqa: E501
        :rtype: str
        """
        return self._versions_url

    @versions_url.setter
    def versions_url(self, versions_url):
        """Sets the versions_url of this CollectionRead.


        :param versions_url: The versions_url of this CollectionRead.  # noqa: E501
        :type: str
        """

        self._versions_url = versions_url

    @property
    def highest_version(self):
        """Gets the highest_version of this CollectionRead.  # noqa: E501


        :return: The highest_version of this CollectionRead.  # noqa: E501
        :rtype: str
        """
        return self._highest_version

    @highest_version.setter
    def highest_version(self, highest_version):
        """Sets the highest_version of this CollectionRead.


        :param highest_version: The highest_version of this CollectionRead.  # noqa: E501
        :type: str
        """

        self._highest_version = highest_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CollectionRead):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CollectionRead):
            return True

        return self.to_dict() != other.to_dict()
