# coding: utf-8

"""
    Pulp 3 API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_ansible
from pulpcore.client.pulp_ansible.models.ansible_collection_version_read import AnsibleCollectionVersionRead  # noqa: E501
from pulpcore.client.pulp_ansible.rest import ApiException

class TestAnsibleCollectionVersionRead(unittest.TestCase):
    """AnsibleCollectionVersionRead unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AnsibleCollectionVersionRead
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_ansible.models.ansible_collection_version_read.AnsibleCollectionVersionRead()  # noqa: E501
        if include_optional :
            return AnsibleCollectionVersionRead(
                artifact = '0', 
                pulp_href = '0', 
                pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                md5 = '0', 
                sha1 = '0', 
                sha224 = '0', 
                sha256 = '0', 
                sha384 = '0', 
                sha512 = '0', 
                id = '0', 
                authors = [
                    '0'
                    ], 
                contents = [
                    {
                        'key' : '0'
                        }
                    ], 
                dependencies = {
                    'key' : '0'
                    }, 
                description = '0', 
                docs_blob = {
                    'key' : '0'
                    }, 
                documentation = '0', 
                homepage = '0', 
                issues = '0', 
                certification = '0', 
                license = [
                    '0'
                    ], 
                name = '0', 
                namespace = '0', 
                repository = '0', 
                tags = [
                    pulpcore.client.pulp_ansible.models.ansible/tag.ansible.Tag(
                        name = '0', )
                    ], 
                version = '0', 
                deprecated = True
            )
        else :
            return AnsibleCollectionVersionRead(
                artifact = '0',
                id = '0',
                authors = [
                    '0'
                    ],
                contents = [
                    {
                        'key' : '0'
                        }
                    ],
                dependencies = {
                    'key' : '0'
                    },
                description = '0',
                docs_blob = {
                    'key' : '0'
                    },
                documentation = '0',
                homepage = '0',
                issues = '0',
                certification = '0',
                license = [
                    '0'
                    ],
                name = '0',
                namespace = '0',
                repository = '0',
                version = '0',
        )

    def testAnsibleCollectionVersionRead(self):
        """Test AnsibleCollectionVersionRead"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
